package com.kuyuntech.cofarcooking.device.sdk.devmode.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorDirections;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorHeightSpeed;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.WorkModes;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.util.TimerTask;

@EqualsAndHashCode(callSuper = true)
@Data
@ToString
public class AutoClean extends BaseDevMode{


    private Long currentSec = 0l;

    private Thread thread;

    private boolean pasue = false;

    private boolean stop = false;


    public AutoClean(){

        this.setMode(WorkModes.AUTO_CLEAN);


        //时间
        this.setDiyCountDown(true);
        this.setTimeChange(false);
        this.setDefaultTime(150);
        this.setMinTime(150);
        this.setMaxTime(150);

        //电机
        this.setDefaultMotorGear(4);
        this.setMinMotorGear(0);
        this.setMaxMotorGear(10);
        this.setMotorGearChange(false);
        this.setMotorDirectionChange(false);
        this.setMaxMotorWithTemp(10);

        //温度
        this.setDefaultTemp(54);
        this.setMinTemp(0);
        this.setMaxTemp(54);
        this.setTempChange(false);
    }


    @Override
    public void onCountDown(TimerTask timer) {

        if(pasue){
            return;
        }

        DevInfo devInfo = CofarSDK.devInfo();


        if (devInfo.getRemainTime() <= 0 && devInfo.getMode().isCountDown() && !stop) {
            this.stop();
            timer.cancel();
            return;
        }


        if (stop) {
            this.stop(false);
            timer.cancel();
            return;
        }

        devInfo.setRemainTime((short) (devInfo.getRemainTime() - 1));


        if(currentSec == 0){
            CofarSDK.cfgHeat((short) 54,CofarSDK.devInfo().getMode().getDefaultHeatMode());
            CofarSDK.confirmConfig();
            CofarSDK.cfgMotorGear((byte) 4);
            CofarSDK.confirmConfig();
        }


        if(currentSec == 90){
            CofarSDK.cfgHeat((short) 0,CofarSDK.devInfo().getMode().getDefaultHeatMode());
            CofarSDK.confirmConfig();
            CofarSDK.cfgMotorGear((byte) 10);
            CofarSDK.confirmConfig();
        }



        currentSec++;

    }


    @Override
    public void start() {
        currentSec = 0L;
        this.stop = false;
        this.pasue = false;
        super.start();
    }

    @Override
    public void pause() {
        this.pasue = true;
        CofarSDK.pauseNatvie();
    }

    @Override
    public void resume() {
        this.pasue = false;
        CofarSDK.resumeNavtive();
    }

    @Override
    public void stop() {
        currentSec = 0L;
        this.stop = true;
        this.pasue = false;
        CofarSDK.stopNative();
        super.stop();
    }

    @Override
    public void stop(boolean tips) {
        currentSec = 0L;
        this.stop = true;
        this.pasue = false;
        super.stop(tips);
    }

}
