package com.kuyuntech.cofarcooking.device.sdk.devmode.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.DevStatus;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorDirections;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorHeightSpeed;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.WorkModes;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;
import lombok.*;

import java.util.Timer;
import java.util.TimerTask;
import java.util.concurrent.FutureTask;
import java.util.logging.Handler;

@EqualsAndHashCode(callSuper = true)
@Data
@ToString
public class Knead extends BaseDevMode{

    private Long currentSec = 0l;

    private Thread thread;

    private boolean pasue = false;

    private boolean autoPasue = false;

    private boolean stop = false;

    public Knead(){

        this.setMode(WorkModes.KNEAD);


        this.setMinTime(2 * 60);
        this.setMaxTime(4 * 60);
        this.setDefaultTime(3* 60);
        this.setDefaultMotorGear(3);
        this.setMinMotorGear(2);
        this.setMaxMotorGear(3);
        this.setMotorGearChange(false);
        this.setMotorDirectionChange(false);
        this.setMinTemp(0);
        this.setMaxTemp(37);
        this.setTempChange(true);
        this.setDiyCountDown(true);
    }



    @Override
    public void start() {
        currentSec = 0L;
        CofarSDK.startNative();
        CofarSDK.cfgMotorGearNative((byte) 3);
        this.stop = false;
    }


    @Override
    public void onCountDown(TimerTask timer) {


        if(!pasue && DevStatus.PAUSE == CofarSDK.devInfo().getStatus()){
            if(!autoPasue){
                return;
            }
        }

        if(pasue){
            return;
        }



        DevInfo devInfo = CofarSDK.devInfo();


        if (devInfo.getRemainTime() <= 0 && devInfo.getMode().isCountDown() && !stop) {
            this.stop();
            timer.cancel();
            return;
        }


        if (stop) {
           this.stop(false);
            timer.cancel();
            return;
        }

        devInfo.setRemainTime((short) (devInfo.getRemainTime() - 1));




        if(currentSec == 27){
            autoPasue=true;
            CofarSDK.pauseNatvie();
        }

        if(currentSec == 30){
            autoPasue=false;
            CofarSDK.cfgMotorDirectionNative(MotorDirections.REVERSE);
            CofarSDK.resumeNavtive();
        }

        if(currentSec == 57){
            autoPasue=true;
            CofarSDK.pauseNatvie();
        }

        if(currentSec == 60){
            autoPasue=false;
            CofarSDK.cfgMotorNative((byte) 2,MotorDirections.FORWARD, MotorHeightSpeed.YES);
            CofarSDK.resumeNavtive();
        }

        if(currentSec == 87){
            autoPasue=true;
            CofarSDK.pauseNatvie();
        }

        if(currentSec == 90){
            autoPasue=false;
            CofarSDK.cfgMotorNative((byte) 2,MotorDirections.REVERSE, MotorHeightSpeed.YES);
            CofarSDK.resumeNavtive();
        }

        if(currentSec == 117){
            autoPasue=true;
            CofarSDK.pauseNatvie();

        }

        if(currentSec == 120){
            autoPasue=false;
//            CofarSDK.pauseNatvie();
            CofarSDK.cfgMotorDirectionNative(MotorDirections.FORWARD);
            CofarSDK.resumeNavtive();
        }

        currentSec++;

    }

    @Override
    public void pause() {
        this.pasue = true;
        CofarSDK.pauseNatvie();
    }

    @Override
    public void resume() {
        this.pasue = false;
        CofarSDK.resumeNavtive();
    }

    @Override
    public void stop() {
        this.stop = true;
        this.pasue = false;
        CofarSDK.stopNative();
        super.stop();
    }

    @Override
    public void stop(boolean tips) {
        this.stop = true;
        this.pasue = false;
        super.stop(tips);
    }

    public static void main(String[] args){

    }


}
